@@ -1,6 +1,6 @@
 package Term::ANSIColor::Concise;
 
-our $VERSION = "2.00_03";
+our $VERSION = "2.00_04";
 
 use v5.14;
 use utf8;
@@ -400,7 +400,7 @@ Term::ANSIColor::Concise - Produce ANSI terminal sequence by concise notation
 
 =head1 VERSION
 
-Version 2.00_03
+Version 2.00_04
 
 
 =head1 DESCRIPTION
@@ -594,9 +594,10 @@ Color names enclosed by angle bracket :
     <medium_aqua_marine>
 
 These colors are defined in 24bit RGB.  Names are case insensitive and
-underscore (<_>) is ignored, but spaces and punctuations are not
-allowed.  So C<aliceblue>, C<AliceBlue>, C<ALICE_BLUE> are valid but
-C<Alice Blue> is not.  See L</COLOR NAMES> section for detail.
+underscore (C<_>) is ignored, but spaces and punctuations are not
+allowed.  So C<< <aliceblue> >>, C<< <AliceBlue> >>, C<< <ALICE_BLUE>
+>> are all valid but C<< <Alice Blue> >> is not.  See L</COLOR NAMES>
+section for detail.
 
 =head2 CSI SEQUENCES and OTHERS
 
